@@ -33,12 +33,13 @@ try:
     # Used only for typing
     from typing import Optional, Tuple, Union  # pylint: disable=unused-import
     from circuitpython_typing.pil import Image
+    from circuitpython_typing import ReadableBuffer
     from adafruit_framebuf import FrameBuffer
     import busio
 except ImportError:
     pass
 
-__version__ = "1.3.7"
+__version__ = "1.4.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_IS31FL3741.git"
 
 _IS3741_ADDR_DEFAULT = 0x30
@@ -233,6 +234,19 @@ class IS31FL3741:
                 i2c.write(self._pixel_buffer, start=180, end=352)
                 self._pixel_buffer[180] = save
 
+    def write(self, mapping: Tuple, buffer: ReadableBuffer) -> None:
+        """
+        Write buf out on the I2C bus to the IS31FL3741.
+
+        :param mapping: map the pixels in the buffer to the order addressed by the driver chip
+        :param buffer: The bytes to clock out. No assumption is made about color order
+        :return: None
+        """
+        for pos, data in enumerate(buffer):
+            if mapping[pos] != 65535:
+                self[mapping[pos]] = data
+        self.show()
+
 
 IS3741_RGB = (0 << 4) | (1 << 2) | (2)  # Encode as R,G,B
 IS3741_RBG = (0 << 4) | (2 << 2) | (1)  # Encode as R,B,G
