@@ -19,14 +19,15 @@ import adafruit_pixelbuf
 
 try:
     # Used only for typing
-    from typing import Optional, Type
+    from typing import Optional, Type, Union
     from types import TracebackType
     import is31fl3741
+    from . import IS31FL3741
 except ImportError:
     pass
 
 
-__version__ = "1.3.7"
+__version__ = "1.4.0"
 # __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_IS31FL3741.git"
 
 
@@ -78,7 +79,7 @@ class IS31FL3741_PixelBuf(adafruit_pixelbuf.PixelBuf):
 
     def __init__(
         self,
-        is31: is31fl3741.IS31FL3741,
+        is31: Union[is31fl3741.IS31FL3741, IS31FL3741],
         mapping: tuple,
         *,
         addr: int = 0x30,
