@@ -11,7 +11,9 @@ from adafruit_led_animation.sequence import AnimationSequence
 from adafruit_is31fl3741.adafruit_ledglasses import MUST_BUFFER, LED_Glasses
 from adafruit_is31fl3741.led_glasses_animation import LED_Glasses_Animation
 
-glasses = LED_Glasses(board.I2C(), allocate=MUST_BUFFER)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
+glasses = LED_Glasses(i2c, allocate=MUST_BUFFER)
 glasses.set_led_scaling(255)
 glasses.global_current = 0xFE
 glasses.enable = True
